pro convert_imacs_to_specpro, imacs1dfile, imacs2dfile, out1dname=out1dname, out2dname=out2dname

;Wrapper to convert DEIMOS spectra reduced with the DEEP2 pipeline to 
;the format readable by specpro.pro.
;
; Inputs:
;
; imacs1dfile - The 1D spectrum to convert, in fits format.
; imacs2dfile - The 2D IMACS spectrum, fits format.
; out1dname -   Optional string input specifying the name of the 1D
;               file for SpecPro. Note that it must follow the general
;               format spec1d.[mask name].[3 digit slit number].[target
;               name].fits. The default name is
;               spec1d.mask.000.object.fits.
; out2dname  -  Optional string input giving 2D file name for
;               SpecPro. Default is spec2d.mask.000.object.fits.  

if n_elements(out1dname) eq 0 then begin
   out1dname = 'spec1d.mask.000.object.fits'
endif
if n_elements(out2dname) eq 0 then begin
   out2dname = 'spec2d.mask.000.object.fits'
endif

flux = mrdfits(imacs1dfile, 0, head)
sigma = mrdfits(imacs1dfile, 1)
ivar = 1 / sigma^2

;get the wavelengths 
crval1=sxpar(head,'CRVAL1')
cd=sxpar(head,'CDELT1')
crpix1=sxpar(head,'CRPIX1')
dim_temp = size(flux)
xtemp = findgen(dim_temp(1))
lambda=crval1+cd*(xtemp+1-crpix1)

new1d = {flux:flux, ivar:ivar, lambda:lambda}

mwrfits, new1d, out1dname, /create

;-------------------------
;Now convert 2D.

;assume 2D is same number of x pixels as 1D, and that there is no
;2D wavelength solution available.

flux = mrdfits(imacs2dfile, 0)
error = mrdfits(imacs2dfile, 1)

ivar =  1 / error^2
idxbad = where(finite(ivar) ne 1)
ivar[idxbad] = 1e-50

sz2D = size(flux)

lambda2d = rebin(lambda, n_elements(lambda), sz2D[2])

new2d = {flux:flux, lambda:lambda2d, ivar:ivar}

mwrfits, new2d, out2dname, /create



end ;convert_imacs_to_specpro.pro







